==> SimplyDualWielding-5.1.0%2B1.21.5-Fabric-sources.jar: eva/dualwielding/network/MinePacket.java <==
package eva.dualwielding.network;

import eva.dualwielding.DualWieldingClient;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2540;
import net.minecraft.class_2792;
import net.minecraft.class_2846;
import net.minecraft.class_8710;
import net.minecraft.class_9094;
import net.minecraft.class_9139;
import net.minecraft.class_9145;
import org.jetbrains.annotations.NotNull;

public final class MinePacket extends class_2846 {


    private MinePacket(MinePayload payload) {
        super(MinePayload.fake(payload.action), payload.pos(), payload.direction(), payload.sequence());
    }

    public MinePacket(class_2338 pos, class_2350 direction, MinePayload.Action action, int sequence) {
        this(new MinePayload(pos, direction, action, sequence));
    }

    public MinePacket(class_2338 pos, class_2350 direction, MinePayload.Action action) {
        this(pos, direction, action, 0);
    }

    @Override
    public @NotNull class_9145<class_2846> method_65080() {
        return class_9094.field_48099;
//        return new PacketType<>(PacketFlow.SERVERBOUND, DualWieldingClient.MINE_PACKET_ID);
    }

    @Override
    public void method_12361(class_2792 handler) {}



    public record MinePayload(class_2338 pos, class_2350 direction, Action action, int sequence) implements class_8710 {
        public static final class_9139<class_2540, MinePayload> STREAM_CODEC = class_8710.method_56484(MinePayload::write, MinePayload::new);
        public static final class_8710.class_9154<MinePayload> TYPE = new class_8710.class_9154<>(DualWieldingClient.MINE_PACKET_ID);

        private MinePayload(class_2540 buf) {
            this(buf.method_10811(), class_2350.method_10143(buf.readByte()), buf.method_10818(Action.class), buf.readInt());
        }

        private void write(class_2540 buf) {
            buf.method_10817(this.action);
            buf.method_10807(this.pos);
            buf.method_52997(this.direction.method_10146());
            buf.method_10804(this.sequence);
        }

        @Override
        public @NotNull class_9154<? extends class_8710> method_56479() {
            return TYPE;
        }

        public enum Action {
            START_DESTROY_BLOCK,
            ABORT_DESTROY_BLOCK,
            STOP_DESTROY_BLOCK,
        }

        public static class_2846.class_2847 fake(Action action) {
            return switch(action) {
                case START_DESTROY_BLOCK -> class_2846.class_2847.field_12968;
                case STOP_DESTROY_BLOCK -> class_2846.class_2847.field_12973;
                case ABORT_DESTROY_BLOCK -> class_2846.class_2847.field_12971;
            };
        }
    }
}

==> SimplyDualWielding-5.1.1%2B1.21.1-Fabric-sources.jar: eva/dualwielding/network/MinePacket.java <==
package eva.dualwielding.network;

import eva.dualwielding.DualWieldingClient;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2540;
import net.minecraft.class_2792;
import net.minecraft.class_2846;
import net.minecraft.class_8710;
import net.minecraft.class_9094;
import net.minecraft.class_9139;
import net.minecraft.class_9145;
import org.jetbrains.annotations.NotNull;

public class MinePacket extends class_2846 {


    private MinePacket(MinePayload payload) {
        super(MinePayload.fake(payload.action), payload.pos(), payload.direction(), payload.sequence());
    }

    public MinePacket(class_2338 pos, class_2350 direction, MinePayload.Action action, int sequence) {
        this(new MinePayload(pos, direction, action, sequence));
    }

    public MinePacket(class_2338 pos, class_2350 direction, MinePayload.Action action) {
        this(pos, direction, action, 0);
    }

    @Override
    public @NotNull class_9145<class_2846> method_55846() {
        return class_9094.field_48099;
//        return new PacketType<>(PacketFlow.SERVERBOUND, DualWieldingClient.MINE_PACKET_ID);
    }

    @Override
    public void method_12361(class_2792 handler) {}



    public record MinePayload(class_2338 pos, class_2350 direction, Action action, int sequence) implements class_8710 {
        public static final class_9139<class_2540, MinePayload> STREAM_CODEC = class_8710.method_56484(MinePayload::write, MinePayload::new);
        public static final class_8710.class_9154<MinePayload> TYPE = new class_8710.class_9154<>(DualWieldingClient.MINE_PACKET_ID);

        private MinePayload(class_2540 buf) {
            this(buf.method_10811(), class_2350.method_10143(buf.readByte()), buf.method_10818(Action.class), buf.readInt());
        }

        private void write(class_2540 buf) {
            buf.method_10817(this.action);
            buf.method_10807(this.pos);
            buf.method_52997(this.direction.method_10146());
            buf.method_10804(this.sequence);
        }

        @Override
        public @NotNull class_9154<? extends class_8710> method_56479() {
            return TYPE;
        }

        public enum Action {
            START_DESTROY_BLOCK,
            ABORT_DESTROY_BLOCK,
            STOP_DESTROY_BLOCK,
        }

        public static class_2846.class_2847 fake(Action action) {
            return switch(action) {
                case START_DESTROY_BLOCK -> class_2846.class_2847.field_12968;
                case STOP_DESTROY_BLOCK -> class_2846.class_2847.field_12973;
                case ABORT_DESTROY_BLOCK -> class_2846.class_2847.field_12971;
            };
        }
    }
}
